@@ -2,7 +2,9 @@ import click
 from omega.cli.convert import convert
 
 
-@click.group()
+@click.group(
+    help="Example: snypr-cli convert -m mapping.yml rules.yml",
+)
 def cli():
     pass
 
